@@ -168,7 +168,9 @@ class _RabaSingleton_MetaClass(type) :
 			columns = {}
 			columnsToLowerCase = {}
 			getFields_rec(name, sqlFields, columns, columnsToLowerCase, dct, bases)
-
+			columns["raba_id"] = 0
+			columns['json'] = 1
+			
 			try :
 				con = RabaConnection(dct['_raba_namespace'])
 			except KeyError :
@@ -282,7 +284,7 @@ class _RabaSingleton_MetaClass(type) :
 
 		if dbLine != None :
 			if ret.fetchone() != None :
-				raise ValueError("More than one object fit the arguments you've prodided to the constructor")
+				raise ValueError("More than one object fit the arguments you've provided to the constructor")
 
 			raba_id = dbLine[0]
 			try :
@@ -298,7 +300,7 @@ class _RabaSingleton_MetaClass(type) :
 				_registerRabaObjectInstance(obj)
 		
 		elif len(params) > 0 : # params provided but no result
-			raise KeyError("Couldn't find any object that fit the arguments you've prodided to the constructor")
+			raise KeyError("Couldn't find any object that fit the arguments you've provided to the constructor")
 		else :
 			obj = type.__call__(cls, *args, **fieldsDct)
 			obj._raba__init__(**fieldsDct)
@@ -567,7 +569,6 @@ class Raba(object):
 				values = self.sqlSave.values()
 				sql = 'INSERT INTO %s (%s) VALUES (%s)' % (self.__class__.__name__, ', '.join(self.sqlSave.keys()), ', '.join(self.sqlSaveQMarks.values()))
 			else :
-				del(self.sqlSave['raba_id'])
 				values = self.sqlSave.values()
 				sql = 'UPDATE %s SET %s = ? WHERE raba_id = ?' % (self.__class__.__name__, ' = ?, '.join(self.sqlSave.keys()))
 				values.append(self.raba_id)
@@ -882,7 +883,7 @@ class RabaList(MutableSequence) :
 						objDct = e.getDctDescription()
 						values.append((self.anchorObj.raba_id, None, RabaFields.RABA_FIELD_TYPE_IS_RABA_OBJECT, e._rabaClass.__name__, e.raba_id, e._raba_namespace))
 					elif isPythonPrimitive(e) :
-						values.append((self.anchorObj.raba_id, e, RabaFields.RABA_FIELD_TYPE_IS_PRIMITIVE), None, None, None)
+						values.append((self.anchorObj.raba_id, e, RabaFields.RABA_FIELD_TYPE_IS_PRIMITIVE, None, None, None))
 					else :
 						values.append((self.anchorObj.raba_id, buffer(cPickle.dumps(e)), RabaFields.RABA_FIELD_TYPE_IS_PRIMITIVE, None, None, None))
 
